Class: ApimaticApi::ProblemDetailsException

Inherits:
APIException
  • Object
show all
Defined in:
lib/apimatic_api/exceptions/problem_details_exception.rb

Overview

ProblemDetails class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(reason, response) ⇒ ProblemDetailsException

The constructor.

Parameters:

  • reason (String)

    The reason for raising an exception.

  • response (HttpResponse)

    The HttpReponse of the API call.



39
40
41
42
43
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 39

def initialize(reason, response)
  super(reason, response)
  hash = APIHelper.json_deserialize(@response.raw_body)
  unbox(hash)
end

Instance Attribute Details

#detailString

TODO: Write general description for this method

Returns:

  • (String)


26
27
28
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 26

def detail
  @detail
end

#errorsHash[String, Object]

TODO: Write general description for this method

Returns:

  • (Hash[String, Object])


34
35
36
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 34

def errors
  @errors
end

#instanceString

TODO: Write general description for this method

Returns:

  • (String)


30
31
32
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 30

def instance
  @instance
end

#statusInteger

TODO: Write general description for this method

Returns:

  • (Integer)


22
23
24
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 22

def status
  @status
end

#titleString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 18

def title
  @title
end

#typeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 14

def type
  @type
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
71
72
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, title: #{@title.inspect}, status:"\
  " #{@status.inspect}, detail: #{@detail.inspect}, instance: #{@instance.inspect}, errors:"\
  " #{@errors.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



60
61
62
63
64
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 60

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, title: #{@title}, status: #{@status}, detail: #{@detail},"\
  " instance: #{@instance}, errors: #{@errors}>"
end

#unbox(hash) ⇒ Object

Populates this object by extracting properties from a hash. response body.

Parameters:

  • hash (Hash)

    The deserialized response sent by the server in the



48
49
50
51
52
53
54
55
56
57
# File 'lib/apimatic_api/exceptions/problem_details_exception.rb', line 48

def unbox(hash)
  return nil unless hash

  @type = hash.key?('type') ? hash['type'] : SKIP
  @title = hash.key?('title') ? hash['title'] : SKIP
  @status = hash.key?('status') ? hash['status'] : SKIP
  @detail = hash.key?('detail') ? hash['detail'] : SKIP
  @instance = hash.key?('instance') ? hash['instance'] : SKIP
  @errors = hash.key?('errors') ? hash['errors'] : SKIP
end