Class: ApimaticApi::SdkGenerationStatusResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApimaticApi::SdkGenerationStatusResponse
- Defined in:
- lib/apimatic_api/models/sdk_generation_status_response.rb
Overview
SdkGenerationStatusResponse Model.
Instance Attribute Summary collapse
-
#errors ⇒ Hash[String, Object]
TODO: Write general description for this method.
-
#status ⇒ Status
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status:, errors: SKIP) ⇒ SdkGenerationStatusResponse
constructor
A new instance of SdkGenerationStatusResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status:, errors: SKIP) ⇒ SdkGenerationStatusResponse
Returns a new instance of SdkGenerationStatusResponse.
40 41 42 43 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 40 def initialize(status:, errors: SKIP) @status = status @errors = errors unless errors == SKIP end |
Instance Attribute Details
#errors ⇒ Hash[String, Object]
TODO: Write general description for this method
18 19 20 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 18 def errors @errors end |
#status ⇒ Status
TODO: Write general description for this method
14 15 16 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 14 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : nil errors = hash.key?('errors') ? hash['errors'] : SKIP # Create object from extracted values. SdkGenerationStatusResponse.new(status: status, errors: errors) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['status'] = 'status' @_hash['errors'] = 'errors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 29 def self.optionals %w[ errors ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} status: #{@status.inspect}, errors: #{@errors.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/apimatic_api/models/sdk_generation_status_response.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} status: #{@status}, errors: #{@errors}>" end |