Class: ApimaticApi::TransformViaUrlRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ApimaticApi::TransformViaUrlRequest
- Defined in:
- lib/apimatic_api/models/transform_via_url_request.rb
Overview
This structure puts together the URL of the file to be transformed, along with the desired export format.
Instance Attribute Summary collapse
-
#export_format ⇒ ExportFormats
The structure contains API specification formats that Transformer can convert to.
-
#url ⇒ String
The URL for the API specification file.
Note: This URL should be publicly accessible.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(url:, export_format:, additional_properties: nil) ⇒ TransformViaUrlRequest
constructor
A new instance of TransformViaUrlRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(url:, export_format:, additional_properties: nil) ⇒ TransformViaUrlRequest
Returns a new instance of TransformViaUrlRequest.
41 42 43 44 45 46 47 48 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 41 def initialize(url:, export_format:, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @url = url @export_format = export_format @additional_properties = additional_properties end |
Instance Attribute Details
#export_format ⇒ ExportFormats
The structure contains API specification formats that Transformer can convert to.
21 22 23 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 21 def export_format @export_format end |
#url ⇒ String
The URL for the API specification file.
Note: This URL should
be publicly accessible.
16 17 18 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 16 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. url = hash.key?('url') ? hash['url'] : nil export_format = hash.key?('export_format') ? hash['export_format'] : nil # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. TransformViaUrlRequest.new(url: url, export_format: export_format, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
24 25 26 27 28 29 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 24 def self.names @_hash = {} if @_hash.nil? @_hash['url'] = 'url' @_hash['export_format'] = 'export_format' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
32 33 34 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 32 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} url: #{@url.inspect}, export_format: #{@export_format.inspect},"\ " additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/apimatic_api/models/transform_via_url_request.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} url: #{@url}, export_format: #{@export_format}, additional_properties:"\ " #{@additional_properties}>" end |